mystic.models module documentation
==================================

abstract_model module
---------------------

.. automodule:: mystic.models.abstract_model
    :members:
    :undoc-members:
    :show-inheritance:

br8 module
----------

.. automodule:: mystic.models.br8
    :members:
    :undoc-members:
    :show-inheritance:

circle module
-------------

.. automodule:: mystic.models.circle
    :members:
    :undoc-members:
    :show-inheritance:

dejong module
-------------

.. automodule:: mystic.models.dejong 
    :members:
    :undoc-members:
    :show-inheritance:

functions module
----------------

.. automodule:: mystic.models.functions 
    :members:
    :undoc-members:
    :show-inheritance:

lorentzian module
-----------------

.. automodule:: mystic.models.lorentzian 
    :members:
    :undoc-members:
    :show-inheritance:

mogi module
-----------

.. automodule:: mystic.models.mogi 
    :members:
    :undoc-members:
    :show-inheritance:

nag module
----------

.. automodule:: mystic.models.nag 
    :members:
    :undoc-members:
    :show-inheritance:

pohlheim module
---------------

.. automodule:: mystic.models.pohlheim 
    :members:
    :undoc-members:
    :show-inheritance:

poly module
-----------

.. automodule:: mystic.models.poly 
    :members:
    :undoc-members:
    :show-inheritance:

schittkowski module
-------------------

.. automodule:: mystic.models.schittkowski
    :members:
    :undoc-members:
    :show-inheritance:

storn module
------------

.. automodule:: mystic.models.storn 
    :members:
    :undoc-members:
    :show-inheritance:

venkataraman module
-------------------

.. automodule:: mystic.models.venkataraman 
    :members:
    :undoc-members:
    :show-inheritance:

wavy module
-----------

.. automodule:: mystic.models.wavy 
    :members:
    :undoc-members:
    :show-inheritance:

wolfram module
--------------

.. automodule:: mystic.models.wolfram 
    :members:
    :undoc-members:
    :show-inheritance:

